/**
 * @file mcp_server.cpp
 * @brief Implementation of the MCP server
 * 
 * This file implements the server-side functionality for the Model Context Protocol.
 * Follows the 2024-11-05 basic protocol specification.
 */

#include "mcp_server.h"

namespace mcp {

server::server(const std::string& host, int port, const std::string& sse_endpoint, const std::string& msg_endpoint_prefix)
    : host_(host), port_(port), sse_endpoint_(sse_endpoint), msg_endpoint_(msg_endpoint_prefix), name_("MCP Server"), version_(MCP_VERSION) {
    
    http_server_ = std::make_unique<httplib::Server>();
    
    // Set default capabilities
    capabilities_ = {
        {"resources", {
            {"subscribe", true},
            {"listChanged", true}
        }}
    };
}

server::~server() {
    stop();
}

bool server::start(bool blocking) {
    if (running_) {
        return true;  // Already running
    }
    
    std::cerr << "启动MCP服务器: " << host_ << ":" << port_ << std::endl;
    
    // 设置CORS处理
    http_server_->Options(".*", [](const httplib::Request& req, httplib::Response& res) {
        res.set_header("Access-Control-Allow-Origin", "*");
        res.set_header("Access-Control-Allow-Methods", "GET, POST, OPTIONS");
        res.set_header("Access-Control-Allow-Headers", "Content-Type");
        res.status = 204; // No Content
    });
    
    // 设置JSON-RPC端点
    http_server_->Post(msg_endpoint_.c_str(), [this](const httplib::Request& req, httplib::Response& res) {
        this->handle_jsonrpc(req, res);
    });

    // 设置SSE端点
    http_server_->Get(sse_endpoint_.c_str(), [this](const httplib::Request& req, httplib::Response& res) {
        this->handle_sse(req, res);
    });
    
    // 启动服务器
    if (blocking) {
        running_ = true;
        std::cerr << "以阻塞模式启动服务器" << std::endl;
        print_status();
        if (!http_server_->listen(host_.c_str(), port_)) {
            running_ = false;
            std::cerr << "无法在 " << host_ << ":" << port_ << " 上启动服务器" << std::endl;
            return false;
        }
        return true;
    } else {
        // 在单独的线程中启动
        server_thread_ = std::make_unique<std::thread>([this]() {
            std::cerr << "在单独的线程中启动服务器" << std::endl;
            if (!http_server_->listen(host_.c_str(), port_)) {
                std::cerr << "无法在 " << host_ << ":" << port_ << " 上启动服务器" << std::endl;
                running_ = false;
                return;
            }
        });
        running_ = true;
        print_status();
        return true;
    }
}

void server::stop() {
    if (!running_) {
        return;
    }
    
    std::cerr << "正在停止MCP服务器..." << std::endl;
    print_status();
    running_ = false;
    
    // 关闭所有SSE连接
    std::vector<std::string> session_ids;
    {
        std::lock_guard<std::mutex> lock(mutex_);
        // 先收集所有会话ID
        for (const auto& [session_id, _] : session_dispatchers_) {
            session_ids.push_back(session_id);
        }
    }
    
    // 关闭每个会话的分发器
    for (const auto& session_id : session_ids) {
        try {
            std::cerr << "关闭会话: " << session_id << std::endl;
            std::lock_guard<std::mutex> lock(mutex_);
            auto it = session_dispatchers_.find(session_id);
            if (it != session_dispatchers_.end()) {
                it->second->close();
            }
        } catch (const std::exception& e) {
            std::cerr << "关闭会话时发生异常: " << session_id << ", " << e.what() << std::endl;
        }
    }
    
    // 等待一段时间，让会话线程有机会自行清理
    std::cerr << "等待会话线程自行清理..." << std::endl;
    std::this_thread::sleep_for(std::chrono::seconds(1));
    
    // 清理剩余的线程
    {
        std::lock_guard<std::mutex> lock(mutex_);
        for (auto& [session_id, thread] : sse_threads_) {
            if (thread && thread->joinable()) {
                try {
                    std::cerr << "分离会话线程: " << session_id << std::endl;
                    thread->detach();
                } catch (const std::exception& e) {
                    std::cerr << "分离会话线程时发生异常: " << session_id << ", " << e.what() << std::endl;
                }
            }
        }
        
        // 清空映射
        session_dispatchers_.clear();
        sse_threads_.clear();
    }
    
    if (http_server_) {
        std::cerr << "停止HTTP服务器..." << std::endl;
        http_server_->stop();
    }
    
    if (server_thread_ && server_thread_->joinable()) {
        std::cerr << "等待服务器线程结束..." << std::endl;
        server_thread_->join();
    }
    
    std::cerr << "MCP服务器已停止" << std::endl;
}

bool server::is_running() const {
    return running_;
}

void server::set_server_info(const std::string& name, const std::string& version) {
    std::lock_guard<std::mutex> lock(mutex_);
    name_ = name;
    version_ = version;
}

void server::set_capabilities(const json& capabilities) {
    std::lock_guard<std::mutex> lock(mutex_);
    capabilities_ = capabilities;
}

void server::register_method(const std::string& method, std::function<json(const json&)> handler) {
    std::lock_guard<std::mutex> lock(mutex_);
    method_handlers_[method] = handler;
}

void server::register_notification(const std::string& method, std::function<void(const json&)> handler) {
    std::lock_guard<std::mutex> lock(mutex_);
    notification_handlers_[method] = handler;
}

void server::register_resource(const std::string& path, std::shared_ptr<resource> resource) {
    std::lock_guard<std::mutex> lock(mutex_);
    resources_[path] = resource;
    
    // Register methods for resource access
    if (method_handlers_.find("resources/read") == method_handlers_.end()) {
        method_handlers_["resources/read"] = [this](const json& params) -> json {
            if (!params.contains("uri")) {
                throw mcp_exception(error_code::invalid_params, "Missing 'uri' parameter");
            }
            
            std::string uri = params["uri"];
            auto it = resources_.find(uri);
            if (it == resources_.end()) {
                throw mcp_exception(error_code::invalid_params, "Resource not found: " + uri);
            }
            
            json contents = json::array();
            contents.push_back(it->second->read());
            
            return json{
                {"contents", contents}
            };
        };
    }
    
    if (method_handlers_.find("resources/list") == method_handlers_.end()) {
        method_handlers_["resources/list"] = [this](const json& params) -> json {
            json resources = json::array();
        
            for (const auto& [uri, res] : resources_) {
                resources.push_back(res->get_metadata());
            }
            
            json result = {
                {"resources", resources}
            };
            
            // Handle pagination if cursor is provided
            if (params.contains("cursor")) {
                // In this implementation, we don't actually paginate
                // but we include the nextCursor field for compatibility
                result["nextCursor"] = "";
            }
            
            return result;
        };
    }
    
    if (method_handlers_.find("resources/subscribe") == method_handlers_.end()) {
        method_handlers_["resources/subscribe"] = [this](const json& params) -> json {
            if (!params.contains("uri")) {
                throw mcp_exception(error_code::invalid_params, "Missing 'uri' parameter");
            }
            
            std::string uri = params["uri"];
            auto it = resources_.find(uri);
            if (it == resources_.end()) {
                throw mcp_exception(error_code::invalid_params, "Resource not found: " + uri);
            }
            
            // In a real implementation, we would register a subscription here
            // For now, just return success
            return json::object();
        };
    }
    
    if (method_handlers_.find("resources/templates/list") == method_handlers_.end()) {
        method_handlers_["resources/templates/list"] = [this](const json& params) -> json {
            // In this implementation, we don't support resource templates
            return json::array();
        };
    }
}

void server::register_tool(const tool& tool, tool_handler handler) {
    std::lock_guard<std::mutex> lock(mutex_);
    tools_[tool.name] = std::make_pair(tool, handler);
    
    // Register methods for tool listing and calling
    if (method_handlers_.find("tools/list") == method_handlers_.end()) {
        method_handlers_["tools/list"] = [this](const json& params) -> json {
            json tools_json = json::array();
            for (const auto& [name, tool_pair] : tools_) {
                tools_json.push_back(tool_pair.first.to_json());
            }
            return tools_json;
        };
    }
    
    if (method_handlers_.find("tools/call") == method_handlers_.end()) {
        method_handlers_["tools/call"] = [this](const json& params) -> json {
            if (!params.contains("name")) {
                throw mcp_exception(error_code::invalid_params, "Missing 'name' parameter");
            }
            
            std::string tool_name = params["name"];
            auto it = tools_.find(tool_name);
            if (it == tools_.end()) {
                throw mcp_exception(error_code::invalid_params, "Tool not found: " + tool_name);
            }
            
            json tool_args = params.contains("arguments") ? params["arguments"] : json::array();

            json tool_result = {
                {"isError", false}
            };

            try {
                tool_result["content"] = it->second.second(tool_args);
            } catch (const std::exception& e) {
                tool_result["isError"] = true;
            }

            return tool_result;
        };
    }
}

std::vector<tool> server::get_tools() const {
    std::lock_guard<std::mutex> lock(mutex_);
    std::vector<tool> tools;
    
    for (const auto& [name, tool_pair] : tools_) {
        tools.push_back(tool_pair.first);
    }
    
    return tools;
}

void server::set_auth_handler(std::function<bool(const std::string&)> handler) {
    std::lock_guard<std::mutex> lock(mutex_);
    auth_handler_ = handler;
}

void server::handle_sse(const httplib::Request& req, httplib::Response& res) {
    // 生成会话ID
    std::string session_id = generate_session_id();
    std::string session_uri = msg_endpoint_ + "?session_id=" + session_id;
    
    std::cerr << "新的SSE连接: 客户端=" << req.remote_addr << ", 会话ID=" << session_id << std::endl;
    std::cerr << "会话URI: " << session_uri << std::endl;
    std::cerr << "请求头: ";
    for (const auto& [key, value] : req.headers) {
        std::cerr << key << "=" << value << " ";
    }
    std::cerr << std::endl;
    
    // 设置SSE响应头
    res.set_header("Content-Type", "text/event-stream");
    res.set_header("Cache-Control", "no-cache");
    res.set_header("Connection", "keep-alive");
    res.set_header("Access-Control-Allow-Origin", "*");
    
    // 创建会话特定的事件分发器
    auto session_dispatcher = std::make_shared<event_dispatcher>();
    
    // 添加会话分发器到映射表
    {
        std::lock_guard<std::mutex> lock(mutex_);
        session_dispatchers_[session_id] = session_dispatcher;
    }
    
    // 创建会话线程，使用值捕获而不是引用捕获
    auto thread = std::make_unique<std::thread>([this, session_id, session_uri, session_dispatcher]() {
        try {
            std::cerr << "SSE会话线程启动: " << session_id << std::endl;
            
            // 发送初始会话URI - 使用endpoint事件类型，符合MCP规范
            std::this_thread::sleep_for(std::chrono::milliseconds(500));
            std::stringstream ss;
            ss << "event: endpoint\ndata: " << session_uri << "\n\n";
            session_dispatcher->send_event(ss.str());
            std::cerr << "发送会话URI: " << session_uri << " 到会话: " << session_id << std::endl;
            
            // 定期发送心跳，检测连接状态
            int heartbeat_count = 0;
            while (running_ && !session_dispatcher->is_closed()) {
                std::this_thread::sleep_for(std::chrono::seconds(10));
                
                // 检查分发器是否已关闭
                if (session_dispatcher->is_closed()) {
                    std::cerr << "会话已关闭，停止心跳: " << session_id << std::endl;
                    break;
                }
                
                // 检查服务器是否仍在运行
                if (!running_) {
                    std::cerr << "服务器已停止，停止心跳: " << session_id << std::endl;
                    break;
                }
                
                // 发送心跳事件 - 使用自定义heartbeat事件类型
                std::stringstream heartbeat;
                heartbeat << "event: heartbeat\ndata: " << heartbeat_count++ << "\n\n";
                
                try {
                    bool sent = session_dispatcher->send_event(heartbeat.str());
                    if (!sent) {
                        std::cerr << "发送心跳失败，客户端可能已关闭连接: " << session_id << std::endl;
                        break;
                    }
                    std::cerr << "发送心跳到会话: " << session_id << ", 计数: " << heartbeat_count << std::endl;
                } catch (const std::exception& e) {
                    std::cerr << "发送心跳失败，假定连接已关闭: " << e.what() << std::endl;
                    break;
                }
            }
            
            std::cerr << "SSE会话线程退出: " << session_id << std::endl;
        } catch (const std::exception& e) {
            std::cerr << "SSE会话线程异常: " << session_id << ", " << e.what() << std::endl;
        }
        
        // 安全地清理资源
        try {
            std::lock_guard<std::mutex> lock(mutex_);
            
            // 先关闭分发器
            auto dispatcher_it = session_dispatchers_.find(session_id);
            if (dispatcher_it != session_dispatchers_.end()) {
                if (!dispatcher_it->second->is_closed()) {
                    dispatcher_it->second->close();
                }
                session_dispatchers_.erase(dispatcher_it);
            }
            
            // 再移除线程
            auto thread_it = sse_threads_.find(session_id);
            if (thread_it != sse_threads_.end()) {
                // 不要在线程内部join或detach自己
                // 只从映射中移除
                thread_it->second.release(); // 释放所有权但不删除线程对象
                sse_threads_.erase(thread_it);
            }
            
            std::cerr << "会话资源已清理: " << session_id << std::endl;
        } catch (const std::exception& e) {
            std::cerr << "清理会话资源时发生异常: " << session_id << ", " << e.what() << std::endl;
        }
    });
    
    // 存储线程
    {
        std::lock_guard<std::mutex> lock(mutex_);
        sse_threads_[session_id] = std::move(thread);
    }
    
    // 设置分块内容提供者
    res.set_chunked_content_provider("text/event-stream", [this, session_id, session_dispatcher](size_t /* offset */, httplib::DataSink& sink) {
        try {
            // 检查会话是否已关闭
            {
                std::lock_guard<std::mutex> lock(mutex_);
                auto it = session_dispatchers_.find(session_id);
                if (it == session_dispatchers_.end() || it->second->is_closed()) {
                    std::cerr << "会话已关闭，停止内容提供: " << session_id << std::endl;
                    
                    // 不在这里清理资源，让会话线程自己清理
                    return false;
                }
            }
            
            // 等待事件
            bool result = session_dispatcher->wait_event(&sink);
            if (!result) {
                std::cerr << "等待事件失败，关闭连接: " << session_id << std::endl;
                
                // 关闭会话分发器，但不清理资源
                {
                    std::lock_guard<std::mutex> lock(mutex_);
                    auto it = session_dispatchers_.find(session_id);
                    if (it != session_dispatchers_.end()) {
                        it->second->close();
                    }
                }
                
                return false;
            }
   
            
            return true;
        } catch (const std::exception& e) {
            std::cerr << "SSE内容提供者异常: " << e.what() << std::endl;
            
            // 关闭会话分发器，但不清理资源
            try {
                std::lock_guard<std::mutex> lock(mutex_);
                auto it = session_dispatchers_.find(session_id);
                if (it != session_dispatchers_.end()) {
                    it->second->close();
                }
            } catch (const std::exception& e2) {
                std::cerr << "关闭会话分发器时发生异常: " << e2.what() << std::endl;
            }
            
            return false;
        }
    });
}

void server::handle_jsonrpc(const httplib::Request& req, httplib::Response& res) {
    // 设置响应头
    res.set_header("Content-Type", "application/json");
    res.set_header("Access-Control-Allow-Origin", "*");
    res.set_header("Access-Control-Allow-Methods", "POST, OPTIONS");
    res.set_header("Access-Control-Allow-Headers", "Content-Type");
    
    // 处理OPTIONS请求（CORS预检）
    if (req.method == "OPTIONS") {
        res.status = 204; // No Content
        return;
    }
    
    // 获取会话ID
    auto it = req.params.find("session_id");
    std::string session_id = it != req.params.end() ? it->second : "";
    
    std::cerr << "收到JSON-RPC请求: 会话ID=" << session_id << ", 路径=" << req.path << std::endl;
    std::cerr << "请求参数: ";
    for (const auto& [key, value] : req.params) {
        std::cerr << key << "=" << value << " ";
    }
    std::cerr << std::endl;
    
    // 检查会话是否存在
    {
        std::lock_guard<std::mutex> lock(mutex_);
        if (!session_id.empty()) {
            std::cerr << "检查会话是否存在: " << session_id << std::endl;
            std::cerr << "当前活跃会话: ";
            for (const auto& [id, _] : session_dispatchers_) {
                std::cerr << id << " ";
            }
            std::cerr << std::endl;
            
            if (session_dispatchers_.find(session_id) == session_dispatchers_.end()) {
                std::cerr << "会话不存在: " << session_id << std::endl;
                json error_response = {
                    {"jsonrpc", "2.0"},
                    {"error", {
                        {"code", static_cast<int>(error_code::invalid_request)},
                        {"message", "Session not found"}
                    }},
                    {"id", nullptr}
                };
                res.set_content(error_response.dump(), "application/json");
                return;
            } else {
                std::cerr << "会话存在: " << session_id << std::endl;
            }
        } else {
            std::cerr << "请求中没有会话ID" << std::endl;
        }
    }
    
    // 解析请求
    json req_json;
    try {
        req_json = json::parse(req.body);
        std::cerr << "请求内容: " << req_json.dump() << std::endl;
    } catch (const json::exception& e) {
        // 无效的JSON
        std::cerr << "解析JSON失败: " << e.what() << std::endl;
        json error_response = {
            {"jsonrpc", "2.0"},
            {"error", {
                {"code", static_cast<int>(error_code::parse_error)},
                {"message", "Parse error: " + std::string(e.what())}
            }},
            {"id", nullptr}
        };
        res.set_content(error_response.dump(), "application/json");
        return;
    }
    
    // 检查是否是批量请求
    if (req_json.is_array()) {
        // 批量请求暂不支持
        std::cerr << "不支持批量请求" << std::endl;
        json error_response = {
            {"jsonrpc", "2.0"},
            {"error", {
                {"code", static_cast<int>(error_code::invalid_request)},
                {"message", "Batch requests are not supported"}
            }},
            {"id", nullptr}
        };
        res.set_content(error_response.dump(), "application/json");
        return;
    }
    
    // 转换为请求对象
    request mcp_req;
    try {
        mcp_req.jsonrpc = req_json["jsonrpc"];
        mcp_req.method = req_json["method"];
        
        if (req_json.contains("id")) {
            mcp_req.id = req_json["id"];
        }
        
        if (req_json.contains("params")) {
            mcp_req.params = req_json["params"];
        }
    } catch (const json::exception& e) {
        // 无效的请求
        std::cerr << "无效的请求: " << e.what() << std::endl;
        json error_response = {
            {"jsonrpc", "2.0"},
            {"error", {
                {"code", static_cast<int>(error_code::invalid_request)},
                {"message", "Invalid request: " + std::string(e.what())}
            }},
            {"id", nullptr}
        };
        res.set_content(error_response.dump(), "application/json");
        return;
    }
    
    // 处理请求
    std::cerr << "处理方法: " << mcp_req.method << std::endl;
    json result = process_request(mcp_req, session_id);
    std::cerr << "响应: " << result.dump() << std::endl;
    res.set_content(result.dump(), "application/json");
}

json server::process_request(const request& req, const std::string& session_id) {
    // 检查是否是通知
    if (req.is_notification()) {
        std::cerr << "处理通知: " << req.method << std::endl;
        // 通知没有响应
        if (req.method == "notifications/initialized") {
            std::cerr << "收到客户端initialized通知，会话: " << session_id << std::endl;
            set_session_initialized(session_id, true);
            std::cerr << "会话已设置为初始化状态: " << session_id << std::endl;
        }
        return json::object();
    }
    
    // 处理方法调用
    try {
        LOG_INFO("处理方法调用: ", req.method);
        
        // 特殊情况：初始化
        if (req.method == "initialize") {
            return handle_initialize(req, session_id);
        } else if (req.method == "ping") {
            // 接收者必须立即响应一个空响应
            LOG_INFO("处理ping请求");
            return response::create_success(req.id, {}).to_json();
        }

        if (!is_session_initialized(session_id)) {
            LOG_WARNING("会话未初始化: ", session_id);
            return response::create_error(
                req.id,
                error_code::invalid_request,
                "Session not initialized"
            ).to_json();
        }
        
        // 查找注册的方法处理器
        std::function<json(const json&)> handler;
        {
            std::lock_guard<std::mutex> lock(mutex_);
            auto it = method_handlers_.find(req.method);
            if (it != method_handlers_.end()) {
                handler = it->second;
            }
        }
        
        if (handler) {
            // 调用处理器
            LOG_INFO("调用方法处理器: ", req.method);
            auto future = thread_pool_.enqueue([handler, params = req.params]() -> json {
                return handler(params);
            });
            json result = future.get();
            
            // 创建成功响应
            LOG_INFO("方法调用成功: ", req.method);
            return response::create_success(req.id, result).to_json();
        }
        
        // 方法未找到
        LOG_WARNING("方法未找到: ", req.method);
        return response::create_error(
            req.id,
            error_code::method_not_found,
            "Method not found: " + req.method
        ).to_json();
    } catch (const mcp_exception& e) {
        // MCP异常
        LOG_ERROR("MCP异常: ", e.what(), ", 代码: ", static_cast<int>(e.code()));
        return response::create_error(
            req.id,
            e.code(),
            e.what()
        ).to_json();
    } catch (const std::exception& e) {
        // 其他异常
        LOG_ERROR("处理请求时发生异常: ", e.what());
        return response::create_error(
            req.id,
            error_code::internal_error,
            "Internal error: " + std::string(e.what())
        ).to_json();
    } catch (...) {
        // 未知异常
        LOG_ERROR("处理请求时发生未知异常");
        return response::create_error(
            req.id,
            error_code::internal_error,
            "Unknown internal error"
        ).to_json();
    }
}

json server::handle_initialize(const request& req, const std::string& session_id) {
    const json& params = req.params;

    std::cerr << "处理initialize请求，会话ID: " << session_id << std::endl;

    // Version negotiation
    if (!params.contains("protocolVersion") || !params["protocolVersion"].is_string()) {
        std::cerr << "缺少protocolVersion参数或格式不正确" << std::endl;
        return response::create_error(
            req.id, 
            error_code::invalid_params, 
            "Expected string for 'protocolVersion' parameter"
        ).to_json();
    }

    std::string requested_version = params["protocolVersion"].get<std::string>();
    std::cerr << "客户端请求的协议版本: " << requested_version << std::endl;

    if (requested_version != MCP_VERSION) {
        std::cerr << "不支持的协议版本: " << requested_version << ", 服务器支持: " << MCP_VERSION << std::endl;
        return response::create_error(
            req.id, 
            error_code::invalid_params, 
            "Unsupported protocol version",
            {
                {"supported", {MCP_VERSION}},
                {"requested", params["protocolVersion"]}
            }
        ).to_json();
    }

    // Extract client info
    std::string client_name = "UnknownClient";
    std::string client_version = "UnknownVersion";
    
    if (params.contains("clientInfo")) {
        if (params["clientInfo"].contains("name")) {
            client_name = params["clientInfo"]["name"];
        }
        if (params["clientInfo"].contains("version")) {
            client_version = params["clientInfo"]["version"];
        }
    }
    
    // Log connection
    std::cerr << "客户端连接: " << client_name << " " << client_version << std::endl;
    
    // Return server info and capabilities
    json server_info = {
        {"name", name_},
        {"version", version_}
    };

    json result = {
        {"protocolVersion", MCP_VERSION},
        {"capabilities", capabilities_},
        {"serverInfo", server_info}
    };

    std::cerr << "初始化成功，等待客户端发送notifications/initialized通知" << std::endl;
    
    return response::create_success(req.id, result).to_json();
}

void server::send_request(const std::string& session_id, const std::string& method, const json& params) {
    // Check if the method is ping or logging
    bool is_allowed_before_init = (method == "ping" || method == "logging");
    
    // Check if client is initialized or if this is an allowed method
    if (!is_allowed_before_init && !is_session_initialized(session_id)) {
        // Client not initialized and method is not allowed before initialization
        std::cerr << "Cannot send " << method << " request to session " << session_id 
                  << " before it is initialized" << std::endl;
        return;
    }
    
    // Create request
    request req = request::create(method, params);
    
    // 获取会话分发器
    std::shared_ptr<event_dispatcher> dispatcher;
    {
        std::lock_guard<std::mutex> lock(mutex_);
        auto it = session_dispatchers_.find(session_id);
        if (it == session_dispatchers_.end()) {
            std::cerr << "会话不存在: " << session_id << std::endl;
            return;
        }
        dispatcher = it->second;
    }
    
    // 发送请求 - 使用message事件类型，符合MCP规范
    std::stringstream ss;
    ss << "event: message\ndata: " << req.to_json().dump() << "\n\n";
    bool result = dispatcher->send_event(ss.str());
    
    if (!result) {
        std::cerr << "向会话发送请求失败: " << session_id << std::endl;
    } else {
        std::cerr << "成功向会话 " << session_id << " 发送请求: " << method << std::endl;
    }
}

// Check if a session is initialized
bool server::is_session_initialized(const std::string& session_id) const {
    std::lock_guard<std::mutex> lock(mutex_);
    auto it = session_initialized_.find(session_id);
    return (it != session_initialized_.end() && it->second);
}

// Set session initialization status
void server::set_session_initialized(const std::string& session_id, bool initialized) {
    std::lock_guard<std::mutex> lock(mutex_);
    session_initialized_[session_id] = initialized;
}

// Generate a random session ID in UUID format
std::string server::generate_session_id() const {
    std::random_device rd;
    std::mt19937 gen(rd());
    std::uniform_int_distribution<> dis(0, 15);
    
    std::stringstream ss;
    ss << std::hex;
    
    // UUID format: 8-4-4-4-12 hexadecimal digits
    for (int i = 0; i < 8; ++i) {
        ss << dis(gen);
    }
    ss << "-";
    
    for (int i = 0; i < 4; ++i) {
        ss << dis(gen);
    }
    ss << "-";
    
    for (int i = 0; i < 4; ++i) {
        ss << dis(gen);
    }
    ss << "-";
    
    for (int i = 0; i < 4; ++i) {
        ss << dis(gen);
    }
    ss << "-";
    
    for (int i = 0; i < 12; ++i) {
        ss << dis(gen);
    }
    
    return ss.str();
}

void server::print_status() const {
    std::lock_guard<std::mutex> lock(mutex_);
    
    std::cerr << "=== MCP服务器状态 ===" << std::endl;
    std::cerr << "服务器地址: " << host_ << ":" << port_ << std::endl;
    std::cerr << "运行状态: " << (running_ ? "运行中" : "已停止") << std::endl;
    std::cerr << "SSE端点: " << sse_endpoint_ << std::endl;
    std::cerr << "消息端点前缀: " << msg_endpoint_ << std::endl;
    
    std::cerr << "活跃会话数: " << session_dispatchers_.size() << std::endl;
    for (const auto& [session_id, dispatcher] : session_dispatchers_) {
        std::cerr << "  - 会话ID: " << session_id << ", 状态: " << (dispatcher->is_closed() ? "已关闭" : "活跃") << std::endl;
    }
    
    std::cerr << "SSE线程数: " << sse_threads_.size() << std::endl;
    
    std::cerr << "注册的方法数: " << method_handlers_.size() << std::endl;
    for (const auto& [method, _] : method_handlers_) {
        std::cerr << "  - " << method << std::endl;
    }
    
    std::cerr << "注册的通知数: " << notification_handlers_.size() << std::endl;
    for (const auto& [method, _] : notification_handlers_) {
        std::cerr << "  - " << method << std::endl;
    }
    
    std::cerr << "注册的资源数: " << resources_.size() << std::endl;
    for (const auto& [path, _] : resources_) {
        std::cerr << "  - " << path << std::endl;
    }
    
    std::cerr << "注册的工具数: " << tools_.size() << std::endl;
    for (const auto& [name, _] : tools_) {
        std::cerr << "  - " << name << std::endl;
    }
    
    std::cerr << "已初始化的会话数: " << session_initialized_.size() << std::endl;
    for (const auto& [session_id, initialized] : session_initialized_) {
        std::cerr << "  - " << session_id << ": " << (initialized ? "已初始化" : "未初始化") << std::endl;
    }
    
    std::cerr << "======================" << std::endl;
}

} // namespace mcp